cgexplore.systems\_optimisation.get\_forcefield\_from\_dict
===========================================================

.. currentmodule:: cgexplore.systems_optimisation

.. autofunction:: get_forcefield_from_dict